@@ -1,4 +1,5 @@
-globalVariables("gIndex")
+if(getRversion() >= '2.15.1') globalVariables("gIndex")
+
 mcoptions <- list(preschedule=FALSE, set.seed=TRUE)
 
 dinvgamma = function (x, shape, scale = 1) 
